@@ -1,4 +1,4 @@
-from typing import List
+from typing import Any, List, Union
 
 import arrow
 
@@ -43,9 +43,8 @@ class Ccp004v1(ClinicalQualityMeasure):
 
         references = ['Canvas Medical CCP, https://canvas-medical.zendesk.com/hc/en-us']
 
-
     @cached_property
-    def date_of_diagnosis(self) -> str:
+    def date_of_diagnosis(self) -> Union[Any, str]:
         actives: List = []
         for item in self.patient.conditions.find(Diabetes):
             actives.extend([period['from'] for period in item['periods'] if period['to'] is None])
