@@ -6,6 +6,7 @@ from typing import Any, Dict, List, Optional, Type
 import arrow
 
 from canvas_workflow_kit.patient_recordset import (
+    AllergyIntoleranceRecordSet,
     PatientRecordSet,
     BillingLineItemRecordSet,
     ConditionRecordSet,
@@ -18,6 +19,7 @@ from canvas_workflow_kit.patient_recordset import (
     MedicationRecordSet,
     MessageRecordSet,
     ProtocolOverrideRecordSet,
+    ReasonForVisitRecordSet,
     ReferralRecordSet,
     ReferralReportRecordSet,
     UpcomingAppointmentNoteRecordSet,
@@ -41,6 +43,7 @@ class Patient:
     SEX_MALE = 'M'
 
     RECORDSET_CLASSES = (
+        AllergyIntoleranceRecordSet,
         BillingLineItemRecordSet,
         ConditionRecordSet,
         ImagingReportRecordSet,
@@ -51,8 +54,11 @@ class Patient:
         LabReportRecordSet,
         MedicationRecordSet,
         ProtocolOverrideRecordSet,
+        ReasonForVisitRecordSet,
         ReferralRecordSet,
         ReferralReportRecordSet,
+        UpcomingAppointmentNoteRecordSet,
+        UpcomingAppointmentRecordSet,
         VitalSignRecordSet,
     )
 
@@ -60,6 +66,9 @@ class Patient:
         self.patient = data.get('patient', None)
         self.active_only = False
 
+        self.allergy_intolerances = AllergyIntoleranceRecordSet.new_from(
+            data.get(AllergyIntoleranceRecordSet.API_UPDATE_FIELD, []))
+
         self.billing_line_items = BillingLineItemRecordSet.new_from(
             data.get(BillingLineItemRecordSet.API_UPDATE_FIELD, []))
 
@@ -90,6 +99,9 @@ class Patient:
         self.protocol_overrides = ProtocolOverrideRecordSet.new_from(
             data.get(ProtocolOverrideRecordSet.API_UPDATE_FIELD, []))
 
+        self.reason_for_visits = ReasonForVisitRecordSet.new_from(
+            data.get(ReasonForVisitRecordSet.API_UPDATE_FIELD, []))
+
         self.referral_reports = ReferralReportRecordSet.new_from(
             data.get(ReferralReportRecordSet.API_UPDATE_FIELD, []))
 
