@@ -695,6 +695,18 @@ class ProtocolOverrideRecordSet(PatientRecordSet):
         return []
 
 
+class ReasonForVisitRecordSet(PatientEventRecordSet):
+    # TO BE DEVELOPED
+    VALID_SYSTEMS: List[str] = [
+        'snomedct',
+        'loinc',
+        'cpt',
+    ]
+    DATE_FIELD = 'created'
+    PATIENT_FIELD = 'reason_for_visits'
+    API_UPDATE_FIELD = 'reasonForVisits'
+
+
 class UpcomingAppointmentRecordSet(PatientRecordSet):
     VALID_SYSTEMS: List[str] = ['canvas', 'internal']
     PATIENT_FIELD = 'upcoming_appointments'
@@ -712,3 +724,10 @@ class MessageRecordSet(PatientRecordSet):
     VALID_SYSTEMS: List[str] = ['canvas', 'internal']
     PATIENT_FIELD = 'messages'
     API_UPDATE_FIELD = 'messages'
+
+
+class AllergyIntoleranceRecordSet(PatientEventRecordSet):
+    VALID_SYSTEMS: List[str] = ['fdb']
+    PATIENT_FIELD = 'allergy_intolerances'
+    API_UPDATE_FIELD = 'allergyIntolerances'
+    DATE_FIELD = 'onsetDate'
