@@ -36,8 +36,6 @@ from canvas_workflow_kit import settings
 from memoization import cached
 from requests.auth import HTTPDigestAuth
 
-from functools import singledispatchmethod
-
 from . import events
 from .constants import CHANGE_TYPE
 from .internal.attrdict import AttrDict
@@ -166,22 +164,15 @@ class ProtocolResult:
             snake_case_type = snakecase(recommendation_class.__name__)
             setattr(self.__class__, f'add_{snake_case_type}', dynamic_class)
 
-    @singledispatchmethod
     def add_recommendation(self, *args, **kwargs):
         """
         Add a recommendation to the recommendations list.
         """
-        print("standard recwith args", *args)
-        recommendation = Recommendation(*args, **kwargs)
-        self.recommendations.append(recommendation)
+        if len(args) > 0 and isinstance(args[0], Recommendation):
+            recommendation = args[0]
+        else:
+            recommendation = Recommendation(*args, **kwargs)
 
-    @add_recommendation.register
-    def _(self, recommendation: Recommendation):
-        """
-        Add a Recommendation class to the recommendations list.
-        Deprecated: use add_recommendation(*args) instead.
-        """
-        print("added rec", recommendation)
         self.recommendations.append(recommendation)
 
     def add_narrative(self, narrative: str):
