@@ -92,6 +92,7 @@ class TestPatient(SDKBaseTest):
     def test_recordset_classes(self):
         tested = self.load_patient('full')
         expected = [
+            'AllergyIntoleranceRecordSet',
             'BillingLineItemRecordSet',
             'ConditionRecordSet',
             'ImagingReportRecordSet',
@@ -102,8 +103,11 @@ class TestPatient(SDKBaseTest):
             'LabReportRecordSet',
             'MedicationRecordSet',
             'ProtocolOverrideRecordSet',
+            'ReasonForVisitRecordSet',
             'ReferralRecordSet',
             'ReferralReportRecordSet',
+            'UpcomingAppointmentNoteRecordSet',
+            'UpcomingAppointmentRecordSet',
             'VitalSignRecordSet',
         ]
         count = 0
@@ -116,6 +120,7 @@ class TestPatient(SDKBaseTest):
     def test_recordset_fields(self):
         tested = self.load_patient('full')
         expected = [
+            'allergy_intolerances',
             'billing_line_items',
             'conditions',
             'imaging_reports',
@@ -126,8 +131,11 @@ class TestPatient(SDKBaseTest):
             'lab_reports',
             'medications',
             'protocol_overrides',
+            'reason_for_visits',
             'referrals',
             'referral_reports',
+            'upcoming_appointment_notes',
+            'upcoming_appointments',
             'vital_signs',
         ]
         self.assertEqual(expected, tested.recordset_fields())
@@ -312,6 +320,7 @@ class TestPatient(SDKBaseTest):
 
     def test_as_dict(self):
         fields = [
+            'allergy_intolerances',
             'billing_line_items',
             'conditions',
             'imaging_reports',
@@ -321,8 +330,11 @@ class TestPatient(SDKBaseTest):
             'lab_reports',
             'medications',
             'protocol_overrides',
+            'reason_for_visits',
             'referrals',
             'referral_reports',
+            'upcoming_appointments',
+            'upcoming_appointment_notes',
             'vital_signs',
         ]
         tested = self.load_patient('full')
